"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var ReactDOM = require("react-dom");
var form_1 = require("../form/form");
var icon_1 = require("./icon");
var Dialog = /** @class */ (function (_super) {
    tslib_1.__extends(Dialog, _super);
    function Dialog() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Dialog.prototype.closeClicked = function () {
        this.close();
    };
    Dialog.prototype.xClicked = function () {
        if (this.props.onXClicked) {
            this.props.onXClicked();
        }
        else {
            this.close();
        }
    };
    Dialog.prototype.close = function () {
        var main = document.querySelector("main");
        if (main && main.classList.contains("dialog-open")) {
            main.classList.remove("dialog-open");
        }
        this.props.onClose();
        this.unmountPortalNode();
    };
    Dialog.prototype.scrollToTop = function () {
        this.dialogContentElement.scrollTop = 0;
    };
    Dialog.prototype.componentDidMount = function () {
        this.dialogContentElement = document.getElementById("dialog-content");
        this.appNode = document.getElementById(this.props.bodyId || "host");
        if (this.props.isOpen) {
            this.renderToPortal(this.props);
        }
    };
    Dialog.prototype.componentWillReceiveProps = function (newProps) {
        var open = newProps.isOpen;
        if (open && open !== this.props.isOpen && this.props.onOpen) {
            this.props.onOpen();
        }
        if (open) {
            this.renderToPortal(newProps);
        }
        if (!open && this.props.isOpen) {
            if (this.props.onClose) {
                this.props.onClose();
            }
            this.unmountPortalNode();
        }
    };
    Dialog.prototype.renderToPortal = function (props) {
        var _this = this;
        var main = document.querySelector("main");
        if (main && !main.classList.contains("dialog-open")) {
            main.classList.add("dialog-open");
        }
        var element = this.renderDialog(props);
        var node = this.portalNode;
        if (node == null) {
            this.portalNode = node = document.createElement("div");
            this.portalNode.classList.add("dialog-layer");
            if (props.closeOnBackgroundClick) {
                this.portalNode.onclick = function (e) {
                    var clickedElement = e.target;
                    if (clickedElement && clickedElement.classList.contains("dialog-layer")) {
                        _this.close();
                    }
                };
            }
            if (props.layerClass) {
                this.portalNode.classList.add(props.layerClass);
            }
            node.id = this.dialogId || form_1.generateUniqueId(function (u) { return "dialog-layer-" + u; });
            this.appNode.appendChild(node);
        }
        // Renders can return null, but ReactDOM.render() doesn't like being asked
        // to render null. If "element" is `null`, just render a noscript element,
        // like React does when an element's render returns null.
        if (element === null) {
            element = React.createFactory("noscript")();
        }
        // use ReactDOM.unstable_renderSubtreeIntoContainer function instead of
        // render. This allows use to retain "this.context" for the "element"
        ReactDOM.unstable_renderSubtreeIntoContainer(this, element, node);
    };
    Dialog.prototype.componentWillUnmount = function () {
        this.unmountPortalNode();
    };
    Dialog.prototype.unmountPortalNode = function () {
        if (!this.portalNode) {
            return;
        }
        this.portalNode.onclick = null;
        var unmounted = ReactDOM.unmountComponentAtNode(this.portalNode);
        if (unmounted) {
            var body = document.getElementById(this.props.bodyId || "host");
            if (body && this.portalNode) {
                body.removeChild(this.portalNode);
            }
        }
        if (this.portalNode) {
            delete this.portalNode;
        }
        return unmounted;
    };
    Dialog.prototype.renderDialog = function (newProps) {
        var _this = this;
        var style = { width: newProps.width || "500px", height: newProps.height || "auto" };
        return (React.createElement("div", { className: "dialog" + (newProps.className ? " " + newProps.className : ""), style: style, id: this.dialogId },
            !newProps.title &&
                React.createElement("div", { className: "dialog-close-button-no-title", onClick: function () { return _this.xClicked(); } },
                    React.createElement(icon_1.Icon, { icon: icon_1.Icon.Icomoon.cross })),
            newProps.title &&
                React.createElement("div", { className: "dialog-header" },
                    newProps.title,
                    React.createElement("div", { className: "dialog-close-button", onClick: function () { return _this.xClicked(); } },
                        React.createElement(icon_1.Icon, { icon: icon_1.Icon.Icomoon.cross }))),
            React.createElement("div", { className: "dialog-content", id: "dialog-content" }, newProps.children),
            newProps.footerContent && React.createElement("div", { className: "dialog-footer" }, newProps.footerContent)));
    };
    Dialog.prototype.render = function () {
        return (React.createElement("noscript", null));
    };
    return Dialog;
}(React.Component));
exports.Dialog = Dialog;
