"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var PropTypes = require("prop-types");
var React = require("react");
var _ = require("underscore");
var classNames_1 = require("../../utilities/classNames");
var formBinders_1 = require("./formBinders");
var formCore_1 = require("./formCore");
var propertyPathResolver_1 = require("./propertyPathResolver");
/** The default Json Entity binder - NOTE, the original instance provided is MUTABLE */
var JsonEntityBinder = /** @class */ (function () {
    function JsonEntityBinder(data) {
        var _this = this;
        this.data = data;
        this.getKeyValue = function (keyName) {
            return _this.data[keyName];
        };
        this.setKeyValue = function (keyName, value) {
            _this.data[keyName] = value;
        };
        this.getValue = function (dataPath) {
            return propertyPathResolver_1.PropertyPathResolver.getValue(_this.data, dataPath);
        };
        this.setValue = function (dataPath, value) {
            propertyPathResolver_1.PropertyPathResolver.setValue(_this.data, dataPath, value);
            _this.lastDataPathSet = dataPath;
        };
        this.toJson = function () {
            return _this.data;
        };
    }
    return JsonEntityBinder;
}());
var FormDataClone = /** @class */ (function () {
    function FormDataClone() {
    }
    FormDataClone.json = function (source) {
        return JSON.parse(JSON.stringify(source));
    };
    FormDataClone.custom = function (source) {
        var clone = _.clone(source);
        _.keys(clone).map(function (key) {
            var value = clone[key];
            if (_.isObject(value)) {
                clone[key] = FormDataClone.custom(value);
            }
        });
        return clone;
    };
    return FormDataClone;
}());
exports.FormDataClone = FormDataClone;
function generateUniqueId(formatter) {
    var u = "" + Math.random();
    return formatter ? formatter(u) : u;
}
exports.generateUniqueId = generateUniqueId;
function extractChildValidationResults(validationResults, dataPath) {
    var vrs = validationResults && _.filter(validationResults, function (vr) { return vr.attribute.indexOf(dataPath + ".") === 0; });
    if (!vrs) {
        return;
    }
    return vrs.map(function (a) { return (tslib_1.__assign({}, a, { attribute: a.attribute.substring(dataPath.length + 1) })); });
}
exports.extractChildValidationResults = extractChildValidationResults;
var ParentFormContext = /** @class */ (function (_super) {
    tslib_1.__extends(ParentFormContext, _super);
    function ParentFormContext() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ParentFormContext.prototype.render = function () {
        var context = Form.getFormContext(this.context);
        if (!context) {
            // tslint:disable-next-line:no-console
            console.error("A ParentFormBinder should be rendered within the context of a parent Form");
        }
        var children = context ? FormElementProcessor.processChildren(context.coreProps, this.props.children, context.notifyChange) : this.props.children;
        return (React.createElement(React.Fragment, null, children));
    };
    ParentFormContext.contextTypes = { form: PropTypes.object };
    return ParentFormContext;
}(React.Component));
exports.ParentFormContext = ParentFormContext;
/**
 * A stateless data bindable form - state is held within the 'dataBinder' property
 * NOTE: This is designed to render all elements in the form on every change. This allows other participating elements to react to these changes
 * NOTE: This element provides a react context, this can be used to get access to the Forms dataBinder (or any parent Form dataBinder when nested)
 */
var Form = /** @class */ (function (_super) {
    tslib_1.__extends(Form, _super);
    function Form() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.preventDefault = function (e) {
            if (_this.props.onSubmit) {
                _this.props.onSubmit();
            }
            e.preventDefault();
            return false;
        };
        _this.setRef = function (r) { return (_this.formDom = r); };
        _this.notifyChange = function () {
            if (_this.props.onDataBinderChange) {
                _this.props.onDataBinderChange(_this.props.dataBinder);
            }
            if (_this.props.onDataChanged) {
                _this.props.onDataChanged(_this.props.dataBinder.toJson());
            }
        };
        return _this;
    }
    Form.getFormContext = function (context) {
        return context.form;
    };
    Form.prototype.componentDidMount = function () {
        if (this.props.focusFirstEmptyInput) {
            var f = this.formDom;
            var inputs = f.querySelectorAll("input[type=text]:not(:disabled), textarea:not(:disabled)");
            if (inputs[0] && !inputs[0].value) {
                inputs[0].focus();
            }
        }
    };
    Form.prototype.getChildContext = function () {
        return {
            form: {
                dataBinder: this.props.dataBinder,
                coreProps: this.props,
                parent: this.context.form,
                notifyChange: this.notifyChange,
            },
        };
    };
    Form.jsonDataBinder = function (data) {
        return new JsonEntityBinder(data);
    };
    Form.jsonDataBinderWithClone = function (data) {
        return new JsonEntityBinder(FormDataClone.custom(data));
    };
    Form.prototype.render = function () {
        var ch = FormElementProcessor.processChildren(this.props, this.props.children, this.notifyChange);
        var hasParentForm = !!Form.getFormContext(this.context);
        var className = classNames_1.ClassHelpers.classNames("form", hasParentForm && "form-nested", this.props.className);
        return hasParentForm ?
            React.createFactory("div")({ className: className, ref: this.setRef }, ch) :
            React.createFactory("form")({ className: className, onSubmit: this.preventDefault, ref: this.setRef }, ch);
    };
    Form.defaultProps = {
        validationMode: "icon",
    };
    Form.contextTypes = { form: PropTypes.object };
    Form.childContextTypes = {
        form: PropTypes.object,
    };
    Form.Bind = new formBinders_1.FormBinder();
    return Form;
}(React.Component));
exports.Form = Form;
var FormElementProcessor = /** @class */ (function () {
    function FormElementProcessor() {
    }
    FormElementProcessor.processChildren = function (formProps, node, notifyChange) {
        var validationResults = formProps.validationResults;
        return React.Children.map(node, function (element) {
            if (!React.isValidElement(element) || !element.props) {
                return element;
            }
            var props = _.extend({}, element.props);
            // TODO: Was this needed - its set below if a form binder exists!
            // if (formProps.validationMode && props["validationMode"]) {
            //   props["validationMode"] = formProps.validationMode;
            // }
            var children = element.props.children;
            var injector = props;
            var formBinder = formCore_1.getFormBinderFromInjector(injector);
            if (formBinder) {
                formCore_1.updateFormBinderInjector(injector, null);
                if (validationResults && validationResults.length) {
                    var vrs = _.find(validationResults, function (vr) { return vr.attribute === formBinder.dataPath; });
                    if (vrs) {
                        formCore_1.DataValidationMessage.set(props, vrs.message);
                    }
                    else {
                        // use for child form
                        var childValidators = extractChildValidationResults(validationResults, formBinder.dataPath);
                        if (childValidators && childValidators.length) {
                            // tslint:disable-next-line:no-string-literal
                            props["validationResults"] = childValidators;
                        }
                    }
                    // tslint:disable-next-line:no-string-literal
                    if (formProps.validationMode && props["validationMode"]) {
                        // tslint:disable-next-line:no-string-literal
                        props["validationMode"] = formProps.validationMode;
                    }
                }
                formBinder.setElementProperty(props, formProps.dataBinder, validationResults);
                formBinder.handleValueChanged(props, formProps.dataBinder, notifyChange);
                if (formBinder.extender) {
                    formBinder.extender(props, formProps.dataBinder, notifyChange);
                }
                if (formBinder.overrideChildren) {
                    var newChildren = formBinder.overrideChildren(props, formProps.dataBinder);
                    if (typeof newChildren !== undefined) {
                        children = FormElementProcessor.processChildren(formProps, newChildren, notifyChange);
                    }
                }
            }
            else if (children) {
                children = FormElementProcessor.processChildren(formProps, children, notifyChange);
            }
            return React.cloneElement(element, props, children);
        });
    };
    return FormElementProcessor;
}());
