"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var moment = require("moment");
var React = require("react");
var ReactDOM = require("react-dom");
var _ = require("underscore");
var config_1 = require("../../../config/config");
var classNames_1 = require("../../../utilities/classNames");
var icon_1 = require("../../display/icon");
var grid_1 = require("../../layout/grid");
var formCore_1 = require("../formCore");
var validationWrapper_1 = require("../validationWrapper");
var isoFormat = "YYYY-MM-DD";
var CalendarInput = /** @class */ (function (_super) {
    tslib_1.__extends(CalendarInput, _super);
    function CalendarInput(props) {
        var _this = _super.call(this, props) || this;
        if (!config_1.isLocaleSet()) {
            // tslint:disable-next-line:no-console
            console.warn("Using CalendarInput without setting the global Armstrong locale is not recommended. See https://github.com/Rocketmakers/armstrong-react#form---calendar--datepickers");
        }
        _this.format = _this.props.nativeInput ? isoFormat : props.format;
        var initialDate = props.date ? moment(props.date, isoFormat, true) : null;
        var inputValue = "";
        var selectedMonthStart = moment().startOf("month");
        if (initialDate) {
            inputValue = initialDate.format(_this.format);
            selectedMonthStart = initialDate.clone().startOf("month");
        }
        _this.state = { inputValue: inputValue, pickerBodyVisible: false, showOnTop: false, calendarOffset: 0, selectedMonthStart: selectedMonthStart };
        return _this;
    }
    CalendarInput.prototype.onDaySelected = function (date) {
        if (!this.fallsWithinRange(date)) {
            return;
        }
        var newDate = date.clone();
        this.setState({ pickerBodyVisible: false, inputValue: newDate.format(this.format) });
        if (this.props.onDateChanged) {
            this.props.onDateChanged(newDate.format(isoFormat));
        }
    };
    CalendarInput.prototype.isEndOfMonth = function (date) {
        var endOfMonth = date.clone().endOf("month");
        return endOfMonth.isSame(date, "day");
    };
    CalendarInput.prototype.fallsWithinRange = function (date) {
        if (this.props.min && date.isBefore(moment(this.props.min, isoFormat, true), "day")) {
            return false;
        }
        if (this.props.max && date.isAfter(moment(this.props.max, isoFormat, true), "day")) {
            return false;
        }
        return true;
    };
    CalendarInput.prototype.calcTop = function () {
        if (this.inputElement) {
            var bounds = this.inputElement.getBoundingClientRect();
            this.setState({ calendarOffset: bounds.bottom });
        }
    };
    CalendarInput.prototype.getDaysInMonth = function () {
        var days = [];
        var a = this.state.selectedMonthStart.clone().startOf("month").startOf("day");
        var b = a.clone().endOf("month");
        var firstDay = false;
        for (var m = moment(a); m.isBefore(b); m.add(1, "days")) {
            if (!firstDay) {
                firstDay = true;
                var firstDayIndex = m.weekday();
                for (var i = firstDayIndex; i > 0; i--) {
                    days.push(this.getDayComponent(true, this.onDaySelected.bind(this), m.clone().subtract(i, "days")));
                }
            }
            days.push(this.getDayComponent(false, this.onDaySelected.bind(this), m.clone()));
            if (this.isEndOfMonth(m)) {
                var lastDayIndex = m.weekday();
                for (var i = 1; i < 7 - lastDayIndex; i++) {
                    days.push(this.getDayComponent(true, this.onDaySelected.bind(this), m.clone().add(i, "days")));
                }
            }
        }
        return days;
    };
    CalendarInput.prototype.getDayComponent = function (notInCurrentMonth, dayClicked, date) {
        var d = date.clone();
        var dateWithinRange = this.fallsWithinRange(d);
        var isSelected = d.format(isoFormat) === this.props.date;
        var isToday = d.clone().startOf("day").isSame(moment().startOf("day"));
        return React.createElement(CalendarDay, { key: "Calendar_day_" + date.format("DDMMYYYY"), selected: isSelected, isToday: isToday, withinRange: dateWithinRange, notInCurrentMonth: notInCurrentMonth, dayClicked: dayClicked, date: d });
    };
    CalendarInput.prototype.changeMonth = function (increment) {
        var _this = this;
        this.setState({ selectedMonthStart: this.state.selectedMonthStart.clone().add(increment, "months") }, function () {
            _this.shouldShowOnTop();
        });
    };
    CalendarInput.prototype.checkDate = function (dateString) {
        if (dateString === this.state.inputValue) {
            return;
        }
        var m = moment(dateString, this.format, false);
        if (m.isValid() && this.fallsWithinRange(m)) {
            var formattedDate = m.format(this.format);
            if (this.props.onDateChanged) {
                this.props.onDateChanged(m.format(isoFormat));
            }
        }
        else {
            this.resetState(this.props);
        }
    };
    CalendarInput.prototype.componentWillUnmount = function () {
        if (!this.props.nativeInput) {
            window.removeEventListener("mousedown", this);
        }
    };
    CalendarInput.prototype.componentDidMount = function () {
        if (!this.props.nativeInput) {
            window.addEventListener("mousedown", this);
        }
    };
    CalendarInput.prototype.componentWillReceiveProps = function (nextProps) {
        if (this.props.date !== nextProps.date) {
            this.resetState(nextProps);
        }
    };
    CalendarInput.prototype.handleEvent = function (e) {
        var domNode = ReactDOM.findDOMNode(this);
        if (domNode.contains(e.target) && e.type !== "mousewheel" && e.type !== "keydown") {
            return;
        }
        // tslint:disable-next-line:no-string-literal
        if (e.type === "keydown" && e["keyCode"] !== 9) {
            return;
        }
        document.removeEventListener("mousewheel", this, false);
        if (!this.state.inputValue) {
            this.resetState(this.props);
        }
        else {
            this.setState({ pickerBodyVisible: false });
        }
    };
    CalendarInput.prototype.resetState = function (props) {
        var selectedDate = props.date ? moment(props.date, isoFormat, true) : null;
        if (selectedDate) {
            this.setState({
                pickerBodyVisible: false,
                inputValue: selectedDate.format(this.format),
                selectedMonthStart: selectedDate.clone().startOf("month"),
            });
        }
        else {
            this.setState({
                pickerBodyVisible: false,
                inputValue: "",
                selectedMonthStart: moment().startOf("month"),
            });
        }
    };
    CalendarInput.prototype.onInputFocus = function () {
        var _this = this;
        document.addEventListener("mousewheel", this, false);
        this.calcTop();
        this.setState({ pickerBodyVisible: true }, function () {
            _this.shouldShowOnTop();
        });
    };
    CalendarInput.prototype.shouldShowOnTop = function () {
        if (this.props.nativeInput || !this.inputElement) {
            return;
        }
        var height = this.bodyElement.clientHeight + 50;
        var visibleBottom = (window.innerHeight + window.scrollY);
        var inputRect = this.inputElement.getBoundingClientRect();
        var remainingSpace = window.innerHeight - inputRect.bottom;
        if (remainingSpace < height) {
            this.setState({ showOnTop: true });
            return true;
        }
        else {
            this.setState({ showOnTop: false });
            return false;
        }
    };
    CalendarInput.prototype.propsDateAsMoment = function () {
        return moment(this.props.date, isoFormat, true);
    };
    CalendarInput.prototype.render = function () {
        var _this = this;
        var validationMessage = formCore_1.DataValidationMessage.get(this.props);
        var _a = this.props, icon = _a.icon, placeholder = _a.placeholder, alwaysShowCalendar = _a.alwaysShowCalendar, disableClear = _a.disableClear, onDateChanged = _a.onDateChanged, className = _a.className, disabled = _a.disabled, validationMode = _a.validationMode, nativeInput = _a.nativeInput, min = _a.min, max = _a.max, date = _a.date;
        var _b = this.state, selectedMonthStart = _b.selectedMonthStart, pickerBodyVisible = _b.pickerBodyVisible, showOnTop = _b.showOnTop, inputValue = _b.inputValue, calendarOffset = _b.calendarOffset;
        var weekdays = _.range(0, 7).map(function (n) { return React.createElement("div", { className: "date-picker-week-day", key: "day_name_" + n }, moment().startOf("week").add(n, "days").format("dd")); });
        var days = this.getDaysInMonth();
        var currentDisplayDate = selectedMonthStart.format("MMMM - YYYY");
        var classes = classNames_1.ClassHelpers.classNames("date-picker-body", {
            "date-picker-body-visible": pickerBodyVisible && !alwaysShowCalendar,
            "date-picker-top": showOnTop,
            "always-show-calendar": alwaysShowCalendar,
        });
        var rootClasses = classNames_1.ClassHelpers.classNames("date-picker", "armstrong-input", className, {
            "has-icon": icon !== null,
            "disabled": disabled,
            "show-validation": (validationMode !== "none" && validationMessage),
        });
        if (nativeInput) {
            return (React.createElement("div", { className: rootClasses },
                icon && React.createElement(icon_1.Icon, { icon: icon }),
                React.createElement("input", tslib_1.__assign({ ref: function (i) { return _this.inputElement = i; } }, formCore_1.DataValidationMessage.spread(validationMessage), { type: "date", min: min || "", max: max || "", onChange: function (e) { return _this.checkDate(e.target.value); }, value: this.propsDateAsMoment().format(this.format), placeholder: placeholder }))));
        }
        return (React.createElement("div", { className: rootClasses },
            React.createElement(icon_1.Icon, { icon: icon || icon_1.Icon.Icomoon.calendar2 }),
            !alwaysShowCalendar &&
                React.createElement("input", tslib_1.__assign({ className: "cal-input", ref: function (i) { return _this.inputElement = i; } }, formCore_1.DataValidationMessage.spread(validationMessage), { disabled: disabled, type: "text", value: inputValue, onKeyDown: function (e) { return _this.handleEvent(e.nativeEvent); }, onFocus: function (e) { return _this.onInputFocus(); }, onChange: function (e) { }, placeholder: placeholder })),
            !alwaysShowCalendar && date && !disableClear &&
                React.createElement("div", { className: "clear-date-button", onClick: function () { return onDateChanged(null); } },
                    React.createElement(icon_1.Icon, { icon: icon_1.Icon.Icomoon.cross })),
            React.createElement("div", { ref: function (b) { return _this.bodyElement = b; }, className: classes, style: { top: calendarOffset + "px" } },
                React.createElement("div", { className: "date-picker-body-wrapper" },
                    React.createElement(grid_1.Grid, { className: "date-picker-header" },
                        React.createElement(grid_1.Row, null,
                            React.createElement(grid_1.Col, { onClick: function () { return _this.changeMonth(-1); }, width: "auto" }, "<"),
                            React.createElement(grid_1.Col, null, currentDisplayDate),
                            React.createElement(grid_1.Col, { onClick: function () { return _this.changeMonth(1); }, width: "auto" }, ">"))),
                    React.createElement("div", { className: "date-picker-days" },
                        weekdays,
                        days))),
            React.createElement(validationWrapper_1.ValidationLabel, { message: validationMessage, mode: validationMode })));
    };
    CalendarInput.defaultProps = {
        format: "L",
        validationMode: "none",
    };
    return CalendarInput;
}(React.Component));
exports.CalendarInput = CalendarInput;
var CalendarDay = /** @class */ (function (_super) {
    tslib_1.__extends(CalendarDay, _super);
    function CalendarDay() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalendarDay.prototype.render = function () {
        var _a = this.props, notInCurrentMonth = _a.notInCurrentMonth, selected = _a.selected, isToday = _a.isToday, withinRange = _a.withinRange, date = _a.date, dayClicked = _a.dayClicked;
        var classes = classNames_1.ClassHelpers.classNames({
            "not-in-month": notInCurrentMonth,
            "selected-day": selected,
            "is-today": isToday,
            "day-disabled": !withinRange,
        });
        return React.createElement("div", { className: classes, onClick: function () { return dayClicked(date); } }, date.format("DD"));
    };
    return CalendarDay;
}(React.Component));
