"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var _ = require("underscore");
var classNames_1 = require("../../../utilities/classNames");
var dateHelpers_1 = require("../../../utilities/dateHelpers");
var formatting_1 = require("../../../utilities/formatting");
var grid_1 = require("../../layout/grid");
var form_1 = require("../form");
var form_2 = require("../form");
var formCore_1 = require("../formCore");
var validationWrapper_1 = require("../validationWrapper");
var options_1 = require("./options");
var DateInput = /** @class */ (function (_super) {
    tslib_1.__extends(DateInput, _super);
    function DateInput(props) {
        var _this = _super.call(this, props) || this;
        _this.cId = form_2.generateUniqueId(function (u) { return "di_" + u; });
        _this.handleDataChanged = function (d) {
            var _a = _this.props, datePartOrder = _a.datePartOrder, onChange = _a.onChange;
            var date = dateHelpers_1.DateHelpers.toDateFormat(d);
            var day = datePartOrder.indexOf("day") === -1 ? { day: 1 } : undefined;
            var year = datePartOrder.indexOf("year") === -1 ? { year: 2000 } : undefined;
            _this.setState(_.extend({}, d, { date: date }, day, year), function () {
                if (onChange && date) {
                    onChange(date);
                }
            });
        };
        _this.validateProps(props);
        _this.state = { day: null, month: null, year: null, date: null };
        return _this;
    }
    DateInput.prototype.getDaysArrayByMonth = function () {
        return dateHelpers_1.DateHelpers.getDaysArrayByMonth(this.state.month, this.state.year);
    };
    DateInput.prototype.componentWillMount = function () {
        if (this.props.date) {
            this.setState(dateHelpers_1.DateHelpers.getDateParts(this.props.date));
        }
    };
    DateInput.prototype.validateProps = function (props) {
        if (props.datePartOrder.indexOf("month") === -1) {
            // tslint:disable-next-line:no-console
            console.error("A DateInput must include `month` in the datePartOrder");
        }
    };
    DateInput.prototype.componentWillReceiveProps = function (newProps) {
        this.validateProps(newProps);
        if (newProps.date !== this.props.date) {
            if (newProps.date) {
                this.setState(dateHelpers_1.DateHelpers.getDateParts(newProps.date, true));
            }
            else {
                this.setState({ day: null, month: null, year: null, date: null });
            }
        }
    };
    DateInput.prototype.render = function () {
        var validationMessage = formCore_1.DataValidationMessage.get(this.props);
        var _a = this.props, dayLabel = _a.dayLabel, monthLabel = _a.monthLabel, yearLabel = _a.yearLabel, futureDates = _a.futureDates, yearsFromNow = _a.yearsFromNow, startYearCap = _a.startYearCap, className = _a.className, validationMode = _a.validationMode, disabled = _a.disabled, datePartOrder = _a.datePartOrder, tabIndex = _a.tabIndex;
        var options = {
            day: options_1.buildOptions(dayLabel, this.getDaysArrayByMonth(), function (v) { return v; }, function (v) { return formatting_1.Formatting.twoDigitNumber(parseInt(v, 10)); }),
            month: options_1.buildOptions(monthLabel, dateHelpers_1.DateHelpers.getMonthValues(), function (v) { return v.value; }, function (v) { return v.label; }),
            year: options_1.buildOptions(yearLabel, dateHelpers_1.DateHelpers.getYearValues(futureDates, yearsFromNow, startYearCap), function (v) { return v; }, function (v) { return v.toString(); }),
        };
        var classes = classNames_1.ClassHelpers.classNames("armstrong-input", "date-input", className, {
            "show-validation": (validationMode !== "none" && validationMessage),
            "input-disabled": disabled,
        });
        return (React.createElement(form_1.Form, { className: classes, title: validationMessage, onDataChanged: this.handleDataChanged, dataBinder: form_1.Form.jsonDataBinder(this.state) },
            React.createElement(grid_1.Grid, null,
                React.createElement(grid_1.Row, null, datePartOrder.map(function (key, idx) {
                    return (React.createElement(grid_1.Col, { key: idx },
                        React.createElement("select", tslib_1.__assign({ tabIndex: tabIndex }, form_1.Form.Bind.selectNumeric(key), { disabled: disabled }), options[key])));
                })),
                React.createElement(validationWrapper_1.ValidationLabel, { message: validationMessage, mode: validationMode, wrapper: function (p) { return React.createElement(grid_1.Row, { height: "auto" },
                        React.createElement(grid_1.Col, tslib_1.__assign({}, p))); } }))));
    };
    DateInput.defaultProps = {
        yearLabel: "Year",
        monthLabel: "Month",
        dayLabel: "Day",
        datePartOrder: ["day", "month", "year"],
        validationMode: "none",
    };
    return DateInput;
}(React.Component));
exports.DateInput = DateInput;
