import * as React from "react";
import { BgColorClass, FgColorClass, HorizontalAlignment, MarginClass, PaddingClass, VerticalAlignment } from "./../../utilities/uiHelpers";
export interface IGrid extends React.HTMLAttributes<HTMLDivElement> {
    /** (boolean) Wether to render borders around grid parts */
    debugMode?: boolean;
    /** (boolean) ADVANCED: Turns of automatic fix of safari6 compat wrapper */
    disableFlexOverride?: boolean;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
    /** (boolean) Render the first row to simulate a table header */
    table?: boolean;
    /** (boolean) Wether the table should expand and divide to fill its container */
    fillContainer?: boolean;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: keyof React.ReactHTML;
}
export declare class Grid extends React.Component<IGrid, {}> {
    render(): React.DetailedReactHTMLElement<{
        className: string;
    }, HTMLElement>;
    componentDidMount(): void;
}
export interface IRow extends React.HTMLAttributes<HTMLDivElement> {
    /** (number | string) Sets a fixed height for the row, or 'auto' to grow to fit its content */
    height?: number | string;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: string;
    /** (Col[]) A row must contain one or many <Col/> elements */
    children?: React.ReactNode;
}
export declare function Row(props: IRow): React.DOMElement<{
    className: string;
    style: React.CSSProperties;
    /** (Col[]) A row must contain one or many <Col/> elements */
    children?: React.ReactNode;
    defaultChecked?: boolean;
    defaultValue?: string | string[];
    suppressContentEditableWarning?: boolean;
    suppressHydrationWarning?: boolean;
    accessKey?: string;
    contentEditable?: boolean;
    contextMenu?: string;
    dir?: string;
    draggable?: boolean;
    hidden?: boolean;
    id?: string;
    lang?: string;
    placeholder?: string;
    slot?: string;
    spellCheck?: boolean;
    tabIndex?: number;
    title?: string;
    inputMode?: string;
    is?: string;
    radioGroup?: string;
    role?: string;
    about?: string;
    datatype?: string;
    inlist?: any;
    prefix?: string;
    property?: string;
    resource?: string;
    typeof?: string;
    vocab?: string;
    autoCapitalize?: string;
    autoCorrect?: string;
    autoSave?: string;
    color?: string;
    itemProp?: string;
    itemScope?: boolean;
    itemType?: string;
    itemID?: string;
    itemRef?: string;
    results?: number;
    security?: string;
    unselectable?: "on" | "off";
    'aria-activedescendant'?: string;
    'aria-atomic'?: boolean | "false" | "true";
    'aria-autocomplete'?: "none" | "both" | "inline" | "list";
    'aria-busy'?: boolean | "false" | "true";
    'aria-checked'?: boolean | "mixed" | "false" | "true";
    'aria-colcount'?: number;
    'aria-colindex'?: number;
    'aria-colspan'?: number;
    'aria-controls'?: string;
    'aria-current'?: boolean | "time" | "page" | "false" | "true" | "step" | "location" | "date";
    'aria-describedby'?: string;
    'aria-details'?: string;
    'aria-disabled'?: boolean | "false" | "true";
    'aria-dropeffect'?: "none" | "link" | "copy" | "move" | "execute" | "popup";
    'aria-errormessage'?: string;
    'aria-expanded'?: boolean | "false" | "true";
    'aria-flowto'?: string;
    'aria-grabbed'?: boolean | "false" | "true";
    'aria-haspopup'?: boolean | "grid" | "menu" | "listbox" | "false" | "true" | "tree" | "dialog";
    'aria-hidden'?: boolean | "false" | "true";
    'aria-invalid'?: boolean | "false" | "true" | "grammar" | "spelling";
    'aria-keyshortcuts'?: string;
    'aria-label'?: string;
    'aria-labelledby'?: string;
    'aria-level'?: number;
    'aria-live'?: "off" | "assertive" | "polite";
    'aria-modal'?: boolean | "false" | "true";
    'aria-multiline'?: boolean | "false" | "true";
    'aria-multiselectable'?: boolean | "false" | "true";
    'aria-orientation'?: "horizontal" | "vertical";
    'aria-owns'?: string;
    'aria-placeholder'?: string;
    'aria-posinset'?: number;
    'aria-pressed'?: boolean | "mixed" | "false" | "true";
    'aria-readonly'?: boolean | "false" | "true";
    'aria-relevant'?: "all" | "text" | "additions" | "additions text" | "removals";
    'aria-required'?: boolean | "false" | "true";
    'aria-roledescription'?: string;
    'aria-rowcount'?: number;
    'aria-rowindex'?: number;
    'aria-rowspan'?: number;
    'aria-selected'?: boolean | "false" | "true";
    'aria-setsize'?: number;
    'aria-sort'?: "none" | "ascending" | "descending" | "other";
    'aria-valuemax'?: number;
    'aria-valuemin'?: number;
    'aria-valuenow'?: number;
    'aria-valuetext'?: string;
    dangerouslySetInnerHTML?: {
        __html: string;
    };
    onCopy?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCopyCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCut?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCutCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPaste?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPasteCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCompositionEnd?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionEndCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStart?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStartCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdate?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdateCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onFocusCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlur?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlurCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onChange?: (event: React.FormEvent<HTMLDivElement>) => void;
    onChangeCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInput?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInputCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onReset?: (event: React.FormEvent<HTMLDivElement>) => void;
    onResetCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmit?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmitCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalid?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalidCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onLoad?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onError?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onErrorCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onKeyDown?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyDownCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPress?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPressCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUp?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUpCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onAbort?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onAbortCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThrough?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThroughCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptied?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptiedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncrypted?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncryptedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEnded?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEndedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedData?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedDataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadata?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStart?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStartCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPause?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPauseCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlaying?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgress?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgressCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeked?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeking?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalled?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalledCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspend?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspendCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdate?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdateCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaiting?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaitingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenuCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDrag?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnd?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEndCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnter?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnterCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExit?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExitCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeave?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeaveCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOver?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOverCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStart?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStartCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDrop?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDropCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseDownCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMove?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMoveCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOut?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOutCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOver?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOverCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUp?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUpCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onSelect?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSelectCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTouchCancel?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchCancelCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEnd?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEndCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMove?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMoveCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStart?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStartCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onPointerDown?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerDownCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerMove?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerMoveCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerUp?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerUpCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerCancel?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerCancelCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerEnter?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerEnterCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerLeave?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerLeaveCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOver?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOverCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOut?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOutCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onGotPointerCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onGotPointerCaptureCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onLostPointerCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onLostPointerCaptureCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onScroll?: (event: React.UIEvent<HTMLDivElement>) => void;
    onScrollCapture?: (event: React.UIEvent<HTMLDivElement>) => void;
    onWheel?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onWheelCapture?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onAnimationStart?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationStartCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEnd?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEndCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIteration?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIterationCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onTransitionEnd?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    onTransitionEndCapture?: (event: React.TransitionEvent<HTMLDivElement>) => void;
}, Element>;
export interface ICol extends React.HTMLAttributes<HTMLDivElement> {
    /** (HorizontalAlignment(string)) How to align content horizontally in this column */
    horizontalAlignment?: HorizontalAlignment;
    /** (HorizontalAlignment(string)) How to align content vertically in this column */
    verticalAlignment?: VerticalAlignment;
    /** (number | string) Sets a fixed width for the column, or 'auto' to grow to fit its content */
    width?: number | string;
    /** (string) An HTML tag to use for the root element instead of <div> */
    tagName?: string;
    /** (string) CSS classname property */
    className?: string | MarginClass | PaddingClass | BgColorClass | FgColorClass;
}
export declare function Col(props: ICol): React.DOMElement<{
    className: string;
    style: React.CSSProperties;
    defaultChecked?: boolean;
    defaultValue?: string | string[];
    suppressContentEditableWarning?: boolean;
    suppressHydrationWarning?: boolean;
    accessKey?: string;
    contentEditable?: boolean;
    contextMenu?: string;
    dir?: string;
    draggable?: boolean;
    hidden?: boolean;
    id?: string;
    lang?: string;
    placeholder?: string;
    slot?: string;
    spellCheck?: boolean;
    tabIndex?: number;
    title?: string;
    inputMode?: string;
    is?: string;
    radioGroup?: string;
    role?: string;
    about?: string;
    datatype?: string;
    inlist?: any;
    prefix?: string;
    property?: string;
    resource?: string;
    typeof?: string;
    vocab?: string;
    autoCapitalize?: string;
    autoCorrect?: string;
    autoSave?: string;
    color?: string;
    itemProp?: string;
    itemScope?: boolean;
    itemType?: string;
    itemID?: string;
    itemRef?: string;
    results?: number;
    security?: string;
    unselectable?: "on" | "off";
    'aria-activedescendant'?: string;
    'aria-atomic'?: boolean | "false" | "true";
    'aria-autocomplete'?: "none" | "both" | "inline" | "list";
    'aria-busy'?: boolean | "false" | "true";
    'aria-checked'?: boolean | "mixed" | "false" | "true";
    'aria-colcount'?: number;
    'aria-colindex'?: number;
    'aria-colspan'?: number;
    'aria-controls'?: string;
    'aria-current'?: boolean | "time" | "page" | "false" | "true" | "step" | "location" | "date";
    'aria-describedby'?: string;
    'aria-details'?: string;
    'aria-disabled'?: boolean | "false" | "true";
    'aria-dropeffect'?: "none" | "link" | "copy" | "move" | "execute" | "popup";
    'aria-errormessage'?: string;
    'aria-expanded'?: boolean | "false" | "true";
    'aria-flowto'?: string;
    'aria-grabbed'?: boolean | "false" | "true";
    'aria-haspopup'?: boolean | "grid" | "menu" | "listbox" | "false" | "true" | "tree" | "dialog";
    'aria-hidden'?: boolean | "false" | "true";
    'aria-invalid'?: boolean | "false" | "true" | "grammar" | "spelling";
    'aria-keyshortcuts'?: string;
    'aria-label'?: string;
    'aria-labelledby'?: string;
    'aria-level'?: number;
    'aria-live'?: "off" | "assertive" | "polite";
    'aria-modal'?: boolean | "false" | "true";
    'aria-multiline'?: boolean | "false" | "true";
    'aria-multiselectable'?: boolean | "false" | "true";
    'aria-orientation'?: "horizontal" | "vertical";
    'aria-owns'?: string;
    'aria-placeholder'?: string;
    'aria-posinset'?: number;
    'aria-pressed'?: boolean | "mixed" | "false" | "true";
    'aria-readonly'?: boolean | "false" | "true";
    'aria-relevant'?: "all" | "text" | "additions" | "additions text" | "removals";
    'aria-required'?: boolean | "false" | "true";
    'aria-roledescription'?: string;
    'aria-rowcount'?: number;
    'aria-rowindex'?: number;
    'aria-rowspan'?: number;
    'aria-selected'?: boolean | "false" | "true";
    'aria-setsize'?: number;
    'aria-sort'?: "none" | "ascending" | "descending" | "other";
    'aria-valuemax'?: number;
    'aria-valuemin'?: number;
    'aria-valuenow'?: number;
    'aria-valuetext'?: string;
    children?: React.ReactNode;
    dangerouslySetInnerHTML?: {
        __html: string;
    };
    onCopy?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCopyCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCut?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCutCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPaste?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onPasteCapture?: (event: React.ClipboardEvent<HTMLDivElement>) => void;
    onCompositionEnd?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionEndCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStart?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionStartCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdate?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onCompositionUpdateCapture?: (event: React.CompositionEvent<HTMLDivElement>) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onFocusCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlur?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlurCapture?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onChange?: (event: React.FormEvent<HTMLDivElement>) => void;
    onChangeCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInput?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInputCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onReset?: (event: React.FormEvent<HTMLDivElement>) => void;
    onResetCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmit?: (event: React.FormEvent<HTMLDivElement>) => void;
    onSubmitCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalid?: (event: React.FormEvent<HTMLDivElement>) => void;
    onInvalidCapture?: (event: React.FormEvent<HTMLDivElement>) => void;
    onLoad?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onError?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onErrorCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onKeyDown?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyDownCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPress?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyPressCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUp?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onKeyUpCapture?: (event: React.KeyboardEvent<HTMLDivElement>) => void;
    onAbort?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onAbortCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThrough?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onCanPlayThroughCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onDurationChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptied?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEmptiedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncrypted?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEncryptedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEnded?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onEndedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedData?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedDataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadata?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadedMetadataCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStart?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onLoadStartCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPause?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPauseCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlay?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlaying?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onPlayingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgress?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onProgressCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onRateChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeked?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekedCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeeking?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSeekingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalled?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onStalledCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspend?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSuspendCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdate?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTimeUpdateCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChange?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onVolumeChangeCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaiting?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onWaitingCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onContextMenuCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClick?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDoubleClickCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onDrag?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnd?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEndCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnter?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragEnterCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExit?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragExitCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeave?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragLeaveCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOver?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragOverCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStart?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDragStartCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDrop?: (event: React.DragEvent<HTMLDivElement>) => void;
    onDropCapture?: (event: React.DragEvent<HTMLDivElement>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseDownCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMove?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseMoveCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOut?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOutCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOver?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseOverCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUp?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onMouseUpCapture?: (event: React.MouseEvent<HTMLDivElement>) => void;
    onSelect?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onSelectCapture?: (event: React.SyntheticEvent<HTMLDivElement>) => void;
    onTouchCancel?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchCancelCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEnd?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchEndCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMove?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchMoveCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStart?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onTouchStartCapture?: (event: React.TouchEvent<HTMLDivElement>) => void;
    onPointerDown?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerDownCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerMove?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerMoveCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerUp?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerUpCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerCancel?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerCancelCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerEnter?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerEnterCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerLeave?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerLeaveCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOver?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOverCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOut?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onPointerOutCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onGotPointerCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onGotPointerCaptureCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onLostPointerCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onLostPointerCaptureCapture?: (event: React.PointerEvent<HTMLDivElement>) => void;
    onScroll?: (event: React.UIEvent<HTMLDivElement>) => void;
    onScrollCapture?: (event: React.UIEvent<HTMLDivElement>) => void;
    onWheel?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onWheelCapture?: (event: React.WheelEvent<HTMLDivElement>) => void;
    onAnimationStart?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationStartCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEnd?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationEndCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIteration?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onAnimationIterationCapture?: (event: React.AnimationEvent<HTMLDivElement>) => void;
    onTransitionEnd?: (event: React.TransitionEvent<HTMLDivElement>) => void;
    onTransitionEndCapture?: (event: React.TransitionEvent<HTMLDivElement>) => void;
}, Element>;
