"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var ReactDOM = require("react-dom");
var _ = require("underscore");
var classNames_1 = require("../../utilities/classNames");
var uiHelpers_1 = require("./../../utilities/uiHelpers");
var Grid = /** @class */ (function (_super) {
    tslib_1.__extends(Grid, _super);
    function Grid() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Grid.prototype.render = function () {
        var originalClassName = this.props.className;
        var _a = this.props, className = _a.className, debugMode = _a.debugMode, disableFlexOverride = _a.disableFlexOverride, table = _a.table, fillContainer = _a.fillContainer, tagName = _a.tagName, attrs = tslib_1.__rest(_a, ["className", "debugMode", "disableFlexOverride", "table", "fillContainer", "tagName"]);
        var classes = classNames_1.ClassHelpers.classNames(originalClassName, "grid", {
            "fill-container": fillContainer,
            "grid-debug": debugMode,
            "table-grid": table,
        });
        if (fillContainer && !disableFlexOverride) {
            return React.createElement(tagName || "div", { className: "flex-override" }, React.createElement("div", tslib_1.__assign({}, attrs, { className: classes })));
        }
        else {
            return React.createElement(tagName || "div", tslib_1.__assign({}, attrs, { className: classes }));
        }
    };
    Grid.prototype.componentDidMount = function () {
        var _a = this.props, fillContainer = _a.fillContainer, disableFlexOverride = _a.disableFlexOverride;
        if (fillContainer && !disableFlexOverride) {
            ReactDOM.findDOMNode(this).parentElement.style.position = "relative";
        }
    };
    return Grid;
}(React.Component));
exports.Grid = Grid;
function sizeErrorMessage(size, sizeValue, controlPath) {
    return "Unsupported " + size + " property '" + sizeValue + "' on " + controlPath + ". If you are using a string, make sure it is either 'auto' or follows the pattern '[number]*'";
}
function Row(props) {
    var className = props.className, height = props.height, tagName = props.tagName, style = props.style, attrs = tslib_1.__rest(props, ["className", "height", "tagName", "style"]);
    function needsFixed() {
        if (!height) {
            return false;
        }
        if (typeof height === "number") {
            return true;
        }
        else {
            if (height === "auto") {
                return true;
            }
        }
        return false;
    }
    var classes = classNames_1.ClassHelpers.classNames(className, "row", needsFixed() ? "no-flex" : "");
    var styles = style;
    if (height) {
        if (typeof height === "number") {
            styles = _.extend({ height: height + "px" }, styles);
        }
        else {
            var hString = height;
            var starIndex = hString.indexOf("*");
            if (height === "auto") {
                // do nothing
            }
            else if (starIndex !== -1 && parseFloat(hString)) {
                var spans = height.substr(0, starIndex);
                styles = _.extend({ flex: "" + spans }, styles);
            }
            else {
                // tslint:disable-next-line:no-console
                console.error(sizeErrorMessage("height", height, "Grid > Row"));
            }
        }
    }
    return React.createElement(tagName || "div", tslib_1.__assign({}, attrs, { className: classes, style: styles }), React.Children.map(props.children, function (c) {
        return c ? React.cloneElement(c, { style: c.props.style }) : null;
    }));
}
exports.Row = Row;
function Col(props) {
    var className = props.className, width = props.width, horizontalAlignment = props.horizontalAlignment, verticalAlignment = props.verticalAlignment, tagName = props.tagName, style = props.style, attrs = tslib_1.__rest(props, ["className", "width", "horizontalAlignment", "verticalAlignment", "tagName", "style"]);
    function needsFixed() {
        if (!width) {
            return false;
        }
        if (typeof width === "number") {
            return true;
        }
        else {
            if (width === "auto") {
                return true;
            }
        }
        return false;
    }
    var alignmentClasses = uiHelpers_1.LayoutHelpers.GetAlignmentClasses(verticalAlignment, horizontalAlignment);
    var classes = classNames_1.ClassHelpers.classNames("col", className, alignmentClasses, {
        "no-flex": needsFixed(),
    });
    var styles = style;
    if (width) {
        if (typeof width === "number") {
            styles = _.extend({ maxwidth: width + "px", width: "100%" }, styles);
        }
        else {
            var wString = width;
            var starIndex = wString.indexOf("*");
            if (width === "auto") {
                // do nothing
            }
            else if (starIndex !== -1 && parseFloat(wString)) {
                var spans = wString.substr(0, starIndex);
                styles = _.extend({ flex: "" + spans }, styles);
            }
            else {
                // tslint:disable-next-line:no-console
                console.error(sizeErrorMessage("width", width, "Grid > Row > Col"));
            }
        }
    }
    if (typeof width === "number") {
        styles = _.extend({ maxWidth: width + "px", width: "100%" }, styles);
    }
    return React.createElement(tagName || "div", tslib_1.__assign({}, attrs, { className: classes, style: styles }));
}
exports.Col = Col;
