"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var classNames_1 = require("../../utilities/classNames");
var icon_1 = require("./../display/icon");
var TabControl = /** @class */ (function (_super) {
    tslib_1.__extends(TabControl, _super);
    function TabControl(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { selectedTabIndex: 0 };
        return _this;
    }
    TabControl.prototype.changeTab = function (newIndex) {
        var _a = this.props, onTabChanged = _a.onTabChanged, forceSelectedIndex = _a.forceSelectedIndex;
        var tabChanged = function () {
            if (onTabChanged) {
                onTabChanged(newIndex);
            }
        };
        if (forceSelectedIndex === undefined) {
            this.setState({ selectedTabIndex: newIndex }, tabChanged);
        }
        else {
            tabChanged();
        }
    };
    TabControl.prototype.componentWillMount = function () {
        var _a = this.props, defaultSelectedIndex = _a.defaultSelectedIndex, forceSelectedIndex = _a.forceSelectedIndex;
        if (defaultSelectedIndex !== undefined && forceSelectedIndex === undefined) {
            this.setState({ selectedTabIndex: defaultSelectedIndex });
        }
    };
    TabControl.prototype.getSelectedIndex = function () {
        var forceSelectedIndex = this.props.forceSelectedIndex;
        var selectedTabIndex = this.state.selectedTabIndex;
        if (forceSelectedIndex !== undefined) {
            return forceSelectedIndex;
        }
        return selectedTabIndex;
    };
    TabControl.prototype.render = function () {
        var _this = this;
        var tabAlignment = this.props.tabAlignment;
        var _a = this.props, className = _a.className, children = _a.children, onTabChanged = _a.onTabChanged, defaultSelectedIndex = _a.defaultSelectedIndex, forceSelectedIndex = _a.forceSelectedIndex, attrs = tslib_1.__rest(_a, ["className", "children", "onTabChanged", "defaultSelectedIndex", "forceSelectedIndex"]);
        if (!tabAlignment) {
            tabAlignment = "left";
        }
        var classes = classNames_1.ClassHelpers.classNames(className, "tab-control", {
            "tabs-right": tabAlignment === "right",
            "tabs-left": tabAlignment === "left",
        });
        var filteredChildren = React.Children.toArray(children).filter(function (c) { return !!c; });
        var selectedIndex = this.getSelectedIndex();
        return (React.createElement("div", tslib_1.__assign({}, attrs, { className: classes }),
            React.createElement("div", { className: "tab-control-header" }, filteredChildren.map(function (c, i) {
                return React.createElement("div", { key: i, className: "tab-item-header" + (selectedIndex === i ? " selected" : ""), onClick: function () { return _this.changeTab(i); } },
                    c.props.icon ? React.createElement(icon_1.Icon, { className: "m-right-xsmall", icon: c.props.icon }) : null,
                    c.props.title);
            })),
            filteredChildren[selectedIndex]));
    };
    return TabControl;
}(React.Component));
exports.TabControl = TabControl;
var TabItem = /** @class */ (function (_super) {
    tslib_1.__extends(TabItem, _super);
    function TabItem() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TabItem.prototype.render = function () {
        var _a = this.props, className = _a.className, title = _a.title, children = _a.children, attrs = tslib_1.__rest(_a, ["className", "title", "children"]);
        return React.createElement("div", tslib_1.__assign({}, attrs, { className: "tab-content" + (className ? " " + className : "") }), children);
    };
    return TabItem;
}(React.Component));
exports.TabItem = TabItem;
